=======================
Cerberus Access Control
=======================

.. start-badges



|travis|
|codecov|
|landscape|
|codacy|
|version|
|wheel|
|pyup|
|gitter|


.. |travis| image:: https://travis-ci.org/Deavelleye/dj-CerberusAC.svg?branch=master
    :alt: Travis-CI Build Status
    :target: https://travis-ci.org/Deavelleye/dj-CerberusAC/

.. |codecov| image:: https://codecov.io/github/Deavelleye/dj-CerberusAC/coverage.svg?branch=master
    :alt: Coverage Status
    :target: https://codecov.io/github/Deavelleye/dj-CerberusAC/

.. |landscape| image:: https://landscape.io/github/Deavelleye/dj-CerberusAC/master/landscape.svg?style=flat
    :target: https://landscape.io/github/Deavelleye/dj-CerberusAC/
    :alt: Code Quality Status

.. |codacy| image:: https://api.codacy.com/project/badge/Grade/REPLACE_WITH_PROJECT_ID
    :target: https://www.codacy.com/app/Deavelleye/dj-CerberusAC/
    :alt: Codacy Code Quality Status


.. |pyup| image:: https://pyup.io/repos/github/deavelleye/dj-CerberusAC/shield.svg
    :target: https://pyup.io/repos/github/deavelleye/dj-CerberusAC/
    :alt: Updates

.. |gitter| image:: https://badges.gitter.im/Deavelleye/dj-CerberusAC.svg
    :alt: Join the chat at https://gitter.im/Deavelleye/dj-CerberusAC
    :target: https://gitter.im/Deavelleye/dj-CerberusAC?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge

.. |version| image:: https://img.shields.io/pypi/v/django-cerberus-ac.svg?style=flat
    :alt: PyPI Package latest release
    :target: https://pypi.python.org/pypi/django-cerberus-ac/

.. |wheel| image:: https://img.shields.io/pypi/wheel/django-cerberus-ac.svg?style=flat
    :alt: PyPI Wheel
    :target: https://pypi.python.org/pypi/django-cerberus-ac/


.. end-badges

Django Ontology Based Access Control Module

License
=======

Software licensed under `ISC`_ license.

.. _ISC : https://www.isc.org/downloads/software-support-policy/isc-license/

Installation
============

::

    pip install django-cerberus-ac

Documentation
=============

https://github.com/Deavelleye/dj-CerberusAC/wiki

Development
===========

To run all the tests: ``tox``
